%define _plugindir2 %{_libdir}/sasl2

Summary: The Cyrus SASL library.
Name: cyrus-sasl
Version: 2.1.15
Release: 10tr
License: Distributable
Group: Trustix Official
Source0: ftp://ftp.andrew.cmu.edu/pub/cyrus-mail/cyrus-sasl-%{version}.tar.gz
Source1: cyrus-saslauthd.init
Source2: cyrus-saslauthd-sysconfig
Patch0: cyrus-sasl-CAN-2004-0884.patch
URL: http://asg.web.cmu.edu/sasl/sasl-library.html
Buildroot: %{_tmppath}/%{name}-root
BuildRequires: libtool, groff
BuildRequires: db4-devel, openssl-devel, mysql-devel, pam-devel, mysql-libs
Prereq: /sbin/ldconfig, chkconfig, /sbin/service, tsl-utils
Requires: pam, db4, openssl

%description
The %{name} package contains the Cyrus implementation of SASL.
SASL is the Simple Authentication and Security Layer, a method for
adding authentication support to connection-based protocols.


%package devel
Requires: %{name} = %{version}-%{release}
Group: Trustix Official
Summary: Files needed for developing applications with Cyrus SASL.

%description devel
The %{name}-devel package contains files needed for developing and
compiling applications which use the Cyrus SASL library.

%package utils
Group: Trustix Official
Summary: Files needed for runtime applications with Cyrus SASL.

%description utils
The %{name}-libs package contains the runtime libraries for Cyrus SASL.

%package plain
Requires: %{name} = %{version}-%{release}
Group: Trustix Official
Summary: PLAIN and LOGIN support for Cyrus SASL.

%description plain
The %{name}-plain package contains the Cyrus SASL plugins which support
PLAIN and LOGIN authentication schemes.


%package md5
Requires: %{name} = %{version}-%{release}
Group: Trustix Official
Summary: CRAM-MD5 and DIGEST-MD5 support for Cyrus SASL.

%description md5
The %{name}-md5 package contains the Cyrus SASL plugins which support
CRAM-MD5 and DIGEST-MD5 authentication schemes.


%package mysql
Requires: %{name} = %{version}-%{release}
Requires: mysql-libs
Group: Trustix Official
Summary: MySQL support for Cyrus SASL.

%description mysql
The %{name}-mysql package contains the Cyrus SASL plugins which support
MySQL authentication schemes.

%package otp
Requires: %{name} = %{version}-%{release}
Group: Trustix Official
Summary: OTP support for Cyrus SASL.

%description otp
The %{name}-otp package contains the Cyrus SASL plugins which support 
OTP authentication schemes.


%prep
%setup -q -n cyrus-sasl-%{version}
%patch0 -p0


%build
%configure \
        --target %{_arch}-pc-%{_os}-gnu \
        --sysconfdir=%{_sysconfdir}/sasl \
        --enable-static \
        --with-pic \
        --enable-shared \
        --disable-java \
        --with-plugindir=%{_plugindir2} \
        --disable-krb4 \
        --disable-gssapi \
        --with-rc4 \
        --with-dblib=berkeley \
        --with-dbpath=/etc/sasl/sasldb \
        --with-saslauthd=/var/run/saslauthd \
        --without-pwcheck \
        --enable-anon \
        --enable-cram \
        --enable-digest \
        --enable-plain \
        --enable-login \
        --with-pam=/usr/include/security \
        --with-mysql=/usr/include/mysql

make


%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

make install DESTDIR=$RPM_BUILD_ROOT 
install -m755 -d $RPM_BUILD_ROOT%{_bindir}

./libtool --mode=install \
install -m755 sample/client $RPM_BUILD_ROOT%{_bindir}/sasl-sample-client
./libtool --mode=install \
install -m755 sample/server $RPM_BUILD_ROOT%{_bindir}/sasl-sample-server

# Install the saslauthd man page in the expected location, even if it's
# pre-formatted.
install -m755 -d $RPM_BUILD_ROOT%{_mandir}/man8/
# The .8 seems broken
install -m644 saslauthd/*.mdoc $RPM_BUILD_ROOT%{_mandir}/man8/saslauthd.8

# Create the sasldb2 directory.
install -m755 -d $RPM_BUILD_ROOT/%{_sysconfdir}/sasl
touch $RPM_BUILD_ROOT/%{_sysconfdir}/sasl/sasldb
chmod 600 $RPM_BUILD_ROOT/%{_sysconfdir}/sasl/sasldb

# Create the saslauthd listening directory.
install -m755 -d $RPM_BUILD_ROOT/var/run/saslauthd
install -m755 -d $RPM_BUILD_ROOT/etc/init.d
install -m755 %{SOURCE1} $RPM_BUILD_ROOT/etc/init.d/saslauthd
install -m755 -d $RPM_BUILD_ROOT/etc/sysconfig
install -m644 %{SOURCE2} $RPM_BUILD_ROOT/etc/sysconfig/saslauthd


%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT


%post
/sbin/ldconfig
# Make correct symlinks.
/sbin/chkconfig --add saslauthd
# Restart service after upgrade.
/sbin/restart_maybe saslauthd


%preun
if [ $1 = 0 ] ; then
	/etc/init.d/saslauthd stop 2>/dev/null || :
	/sbin/chkconfig --del saslauthd || : 
fi


%postun
/sbin/ldconfig


%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README doc/*.html
%{_libdir}/libsasl*.so.*
%dir %{_plugindir2}/
%dir %{_sysconfdir}/sasl/
%config(noreplace) %attr(600,root,root)%{_sysconfdir}/sasl/sasldb
%dir /var/run/saslauthd/
%{_plugindir2}/*anonymous*.so*
%{_plugindir2}/*sasldb*.so*
%{_mandir}/man8/*
%{_sbindir}/saslauthd
%attr(0755,root,root) /etc/init.d/saslauthd
%config(noreplace) %attr(0644,root,root) /etc/sysconfig/saslauthd

%files utils
%defattr(-,root,root)
%{_sbindir}/saslpasswd2
%{_sbindir}/sasldblistusers2

%files plain
%defattr(-,root,root)
%{_plugindir2}/*plain*.so*
%{_plugindir2}/*login*.so*

%files md5
%defattr(-,root,root)
%{_plugindir2}/*crammd5*.so*
%{_plugindir2}/*digestmd5*.so*

%files mysql
%defattr(-,root,root)
%{_plugindir2}/*mysql*.so*

%files otp
%defattr(-,root,root)
%{_plugindir2}/*otp*.so*

%files devel
%defattr(-,root,root)
%doc doc/*.txt
%{_bindir}/sasl-sample-client
%{_bindir}/sasl-sample-server
%{_includedir}/*
%{_libdir}/libsasl*.*a
%{_libdir}/libsasl*.*so
%{_plugindir2}/*.a
%{_plugindir2}/*.la
%{_mandir}/man3/*


%changelog
* Thu Nov 25 2004 Syed Shabir <syedshabir at comodo dot com> 2.1.15-10tr
- Fixed saslauthd man page bug

* Tue Oct 12 2004 Erlend Midttun <erlendbm at trustix dot org> 2.1.15-9tr
- %config(noreplace) /etc/sysconfig/saslauthd

* Thu Oct  7 2004 Oystein Viggen <oysteivi at trustix dot com> 2.1.15-8tr
- Patch CAN-2004-0884

* Mon Dec 15 2003 Erlend Midttun <erlendbm at trustix dot org> 2.1.15-5tr
- Rebuilt.

* Tue Aug 26 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.15-4tr
- Change deprecated -H option to -O in init script.
- Reformat man page to make it readable.

* Fri Aug 22 2003 Chr. Toldnes <christht at trustix dot com> 2.1.15-3tr
- Rebuild and retag
- Fixed License

* Sun Aug 17 2003 Gerald Dachs <gda at trustix dot org> 2.1.15-2gd
- sasl looks for plugins that have no trailing version numbers
  behind the .so suffix, so I included this files to the plugin
  rpms and removed them from the devel rpm.

* Wed Jul 16 2003 Gerald Dachs <gda at trustix dot org> 2.1.15-1tr
- New upstream.

* Thu Jul  3 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.14-1tr
- New upstream.

* Thu Jun 26 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.13-8tr
- Commented out the TIME_OF_DAY.. in sysconfig
- Moved sasldb to /etc/sasl/

* Mon Jun 23 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.13-7tr
- Added %defattr.

* Fri Jun 20 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.13-6tr
- Added patch to make it work against MySQL v4.

* Wed Jun 18 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.13-5tr
- Big rebuild

* Tue Jun  3 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.13-4em
- Added Req on tsl-utils.

* Tue Apr 29 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.13-3em
- Created utils package for the two files that needs all libraries.

* Mon Apr 28 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.13-2em
- Rebuilt against new mysql.

* Tue Apr 22 2003 Tor Hveem <torh at trustix dot org> 2.1.13-1th
- 2.1.13

* Mon Mar 24 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.12-4em
- Rebuilt against glibc 2.3.2.

* Tue Mar 11 2003 Goetz Bock <bock at trustix dot org> 2.1.12-3bg
- *.la should be part of the devel subpackage

* Tue Mar 11 2003 Goetz Bock <bock at trustix dot org> 2.1.12-2bg
- rebuild against db4.1.25
- cleaned up the SPEC file
- added OTP package

* Tue Feb 04 2003 Tor Hveem <torh at trustix dot org> 2.1.12-1th
- 2.1.12

* Sun Feb 02 2003 Tor Hveem <torh at trustix dot org> 2.1.11-2th
- included saslauthd sysconfig file
- changed the initscript to function with sysconfig file

* Sat Feb 01 2003 Tor Hveem <torh at trustix dot org> 2.1.11-1th
- 2.1.11
- added mysql-libs to build requirements
- fixed typo in Group

* Wed Jan 22 2003 Tor Hveem <torh at trustix dot org> 2.1.10-4th
- fixed $INITLOCK

* Fri Dec 20 2002 Tor Hveem <torh at trustix dot org> 2.1.10-3th
- Added pam authentication

* Thu Dec 19 2002 Gerald Dachs <gda at trustix dot org> 2.1.10-2gd
- changed requirements

* Wed Dec 18 2002 Gerald Dachs <gda at trustix dot org> 2.1.10-1gd
- new upstream version
- fixed saslauthd init script
- changed invokation of functions in saslauthd init script
- don't use %config for saslauthd init script anymore 
- saslauthd init script now uses $INITLOCK

* Thu Aug 22 2002 Gerald Dachs <gda at trustix dot org> 2.1.6-3gd
- changed name to from cyrus-sasl2 to cyrus-sasl
- depends now on db4

* Fri Aug  2 2002 Gerald Dachs <gda at trustix dot org> 2.1.6-2gd
- updated to 2.1.6

* Tue Jul 23 2002 Gerald Dachs <gda at trustix dot org> 2.1.6-1gd
- updated to 2.1.6

* Mon Jun 10 2002 Gerald Dachs <gda at trustix dot org>
- Repacked for Trustix; Based on RPM from Red Hat

